@@ -16,33 +16,24 @@
 because it is used across in several modules inside the app"""
 
 from graphrepo.singleton import Singleton
+from graphrepo.utils import Dotdict
 
 
 class Config(metaclass=Singleton):
-  """This class contains all config flags"""
-  DB_URL = ""
-  PORT = 0
-  DB_USER = ""
-  DB_PWD = ""
-  REPO = ""
-  START_DATE = None
-  END_DATE = None
-  PROJECT_ID = None
-  # If True, each branch will be indexed as a node
-  # and commits will be linked by a Parent relationship
-  # If False, then the commits are linked by a Branch
-  # relationship
-  BRANCH_AS_NODE = True
+    """This class contains all config flags"""
+    ct = {}
 
-  def check_config(self):
-    """Checks if the config properties are set and
-    raises ValueError if any value misses"""
+    def configure(self, **kwargs):
+        """Stores configuration contants, parsed
+        from yaml config file
+        :param kwargs: keys and values from config
+        """
+        self.ct = Dotdict(kwargs)
 
-    if self.DB_URL == "":
-      raise ValueError("Database URL is not set.")
+    def check_config(self):
+        """Checks if the config properties are set and
+        raises ValueError if any value misses"""
 
-    if self.PORT == 0:
-      raise ValueError("Database port is not set.")
-
-    if self.DB_USER == "" or self.DB_PWD == "":
-      raise ValueError("Database credentials are not set.")
+        if not self.ct.db_url or not self.ct.port \
+                or not self.ct.db_user or not self.ct.db_pwd:
+            raise ValueError("Neo4j configuartion is invalid.")
